@@ -60,7 +60,7 @@ class OrderSchema(Schema):
     order_number = fields.String(data_key='orderNumber')
     user_id = fields.Integer(load_only=True, data_key='userID')
     order_date = fields.DateTime(data_key='orderDate')
-    updated_date = fields.DateTime(data_key='updatedDate')
+    updated_date = fields.DateTime(data_key='updatedDate', allow_none=True)
     status = EnumField(OrderStatus, by_value=True)
     contact_email = fields.String(data_key='contactEmail')
     contact_phone = fields.String(data_key='contactPhone')
@@ -68,13 +68,13 @@ class OrderSchema(Schema):
     shipping_zip_code = fields.String(data_key='shippingZipCode')
     shipping_city = fields.String(data_key='shippingCity')
     shipping_address = fields.String(data_key='shippingAddress')
-    shipping_description = fields.String(data_key='shippingDescription')
+    shipping_description = fields.String(data_key='shippingDescription', allow_none=True)
     invoice_name = fields.String(data_key='invoiceName')
     invoice_zip_code = fields.String(data_key='invoiceZipCode')
     invoice_city = fields.String(data_key='invoiceCity')
     invoice_address = fields.String(data_key='invoiceAddress')
-    invoice_tax_number = fields.String(data_key='invoiceTaxNumber')
-    invoice_description = fields.String(data_key='invoiceDescription')
+    invoice_tax_number = fields.String(data_key='invoiceTaxNumber', allow_none=True)
+    invoice_description = fields.String(data_key='invoiceDescription', allow_none=True)
     shipping_method = fields.Integer(data_key='shippingMethod')
     payment_method = fields.Integer(data_key='paymentMethod')
 
